#
# spec file for package hunspell
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ver     1.7
%define libname lib%{name}-1_7-0
Name:           hunspell
Version:        1.7.2
Release:        1.4
Summary:        A spell checker and morphological analyzer library
License:        (GPL-2.0-or-later OR LGPL-2.1-or-later OR MPL-1.1+) AND LGPL-2.1-or-later
Group:          Productivity/Office/Other
URL:            https://hunspell.github.io
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel >= 5.0
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
Recommends:     %{name}-tools
Recommends:     unzip
# bsc#1193627
Requires:       myspell-en_US

%description
Hunspell is a spell checker and morphological analyzer library and
program designed for languages with rich morphology and complex word
compounding or character encoding. Hunspell interfaces: Ispell-like
terminal interface using Curses library, Ispell pipe interface,
LibreOffice or OpenOffice.org UNO module.

%package -n %{libname}
Summary:        A spell checker and morphological analyzer library
# same libname, support migration
Group:          System/Libraries
Conflicts:      hunspell = 1.4.0

%description -n %{libname}
Hunspell is a spell checker and morphological analyzer library and
program designed for languages with rich morphology and complex word
compounding or character encoding. Hunspell interfaces: Ispell-like
terminal interface using Curses library, Ispell pipe interface,
LibreOffice or OpenOffice.org UNO module.

This package contains the shared library.

%package tools
Summary:        Hunspell tools
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description tools
This package contains the munch and unmunch programs.

%package devel
Summary:        Files for developing with hunspell
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}
Requires:       libstdc++-devel

%description devel
Includes and definitions for developing with hunspell.

%prep
%setup -q

%build
# latest released tarball does not contain generated configure
autoreconf -fiv
%configure \
	--disable-silent-rules \
	--enable-nls \
	--disable-static \
	--disable-rpath \
	--with-ui \
	--with-readline
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
rm -f %{buildroot}%{_bindir}/example
install -p -m 644 src/tools/{,un}munch.h %{buildroot}%{_includedir}
ln -sf %{_libdir}/libhunspell-%{ver}.so.0.0.1 %{buildroot}%{_libdir}/libhunspell.so

%check
make check %{?_smp_mflags}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license COPYING license.hunspell license.myspell
%doc README README.md AUTHORS THANKS
%attr(755,root,root) %{_bindir}/hunspell
%dir %{_mandir}/hu
%dir %{_mandir}/hu/man1
%{_mandir}/man1/hunspell.1%{?ext_man}
%lang(hu) %{_mandir}/hu/man1/hunspell.1*

%files -n %{libname}
%{_libdir}/libhunspell-%{ver}.so.*

%files tools
%{_bindir}/analyze
%{_bindir}/chmorph
%{_bindir}/munch
%{_bindir}/unmunch
%{_bindir}/hunzip
%{_bindir}/hzip
%{_bindir}/affixcompress
%{_bindir}/ispellaff2myspell
%{_bindir}/makealias
%{_bindir}/wordforms
%{_bindir}/wordlist2hunspell
%{_mandir}/man1/hunzip.1%{?ext_man}
%{_mandir}/man1/hzip.1%{?ext_man}

%files devel
%{_libdir}/libhunspell-%{ver}.so
%{_libdir}/libhunspell.so
%{_mandir}/man3/hunspell.3%{?ext_man}
%{_mandir}/man5/hunspell.5%{?ext_man}
%{_includedir}/%{name}
%{_includedir}/munch.h
%{_includedir}/unmunch.h
%{_libdir}/pkgconfig/hunspell.pc

%changelog
* Sun Jan  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.2:
  * Crash fixes, code clean-up in ~200 commits
  * tdf#136306 don't accept/suggest typos as 3-or-more-word compound words
  * Prepare optional spelling mode of LibreOffice to not accept/suggest not
    dictionary-based words as compound words
  * Merge in weblate translations
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Merge chromium fix for #714 OOB string write in hunspell
  * Merge firefox fix for #756 various issues parsing incomplete aff files
  * Fix #492 crash with hunspell -l -r
  * Merge in weblate translations
- drop hunspell-CVE-2019-16707.patch (upstream)
* Tue May 10 2022 pgajdos@suse.com
- requires english dictionary [bsc#1199209]
* Thu Jan  6 2022 pgajdos@suse.com
- suggests english dictionary [bsc#1193627]
* Tue Jun  9 2020 pgajdos@suse.com
- security update
- added patches
  fix CVE-2019-16707 [bsc#1151867], invalid read operation in SuggestMgr:leftcommonsubstring in suggestmgr.cxx
  + hunspell-CVE-2019-16707.patch
* Thu Nov 15 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 1.7.0:
  * add SPELLML support for run-time dictionary extensio
  * No annoying suggestion times any more, especially in languages with
    compound word handling and complex morphology
  * Improved, highly customizable suggestions on level of dictionary words
  * Handling multiple word suggestions is much more easier
  * Limit compound overgeneration by dictionary based word pairs
  * makealias dictionary compression
  * Various minor bugfixes
* Fri Oct 27 2017 mpluskal@suse.com
- Update to version 1.6.2:
  * Command line tool:
    + Added German translation
    + Fixed bug with wrong output encoding, not respecting system
    locale.
* Wed Jun  7 2017 mpluskal@suse.com
- Update to version 1.6.1:
  * Library changes:
    + Performance improvements in suggest()
    + Fixes regressions for Hungarian related to compounding.
    + Fixes regressions for Korean related to ICONV.
  * Command line tool:
    + Added Tajik translation
    + Fix regarding serching of OOo dicts installed in user folder
  * Manpages:
    + Fix microsoft-cp1251 to cp1251. Dicts should not use the
    first.
    + Typos.
* Fri Dec 23 2016 mpluskal@suse.com
- Update to version 1.6.0:
  * Changes in the library:
    + Performance improvement in ngsuggest(), suggestions should be
    faster.
    + Revert MAXWORDLEN to 100 as in 1.3.3 for performance reasons.
    + MAXWORDLEN can be set during build time with -D defines.
    + Fix crash when word with 102 consecutive X is spelled.
  * Changes in the command line tool:
    + -D shows all loaded dictionares insted of only the first.
    + -D properly lists all available dictionaries on Windows.
* Thu Dec  1 2016 pgajdos@suse.com
- update to 1.5.4:
  * fix API compatibility with 1.4
* Mon Nov 21 2016 pgajdos@suse.com
- update to 1.5.0:
  * Lot of stability fixes
  * Fixed compilation errors on various systems (Windows, FreeBSD)
  * Small performance improvement compared to 1.4.0
  * API is same as 1.4.
* Tue May 17 2016 jengelh@inai.de
- Drop Requires: pkgconfig because this is already autodetected
  by rpm. Use mode inheritance for defattr. Edit rpm group and
  description a tiny bit.
* Wed May 11 2016 mpluskal@suse.com
- Update baselibs.conf bnc#977784
- Add conflicts to hunspell 1.4.0
* Wed May  4 2016 mpluskal@suse.com
- Update to 1.4.1:
  * Past begin() iterator decrement error
  * VS Debug build threw error on decrement past begin.
- Split shared library
- Do not call autoreconf
- Move manpages to corresponding packages
* Tue Apr 19 2016 mpluskal@suse.com
- Update to 1.4.0
  * New release that strips out fixed length buffers from large
    parts of the library
  * Note: dictmgr.hxx header is dropped
- Drop upstreamed hunspell-grep2.24.patch
* Mon Apr  4 2016 tchvatal@suse.com
- Version update to 1.3.4:
  * Various updates to the buildsystem
  * Various werror bugfixes
  * Loads of coverity fixes
- Add patch to build with grep 2.24:
  * hunspell-grep2.24.patch
- Remove upstreamed patch:
  * hunspell-emacs-utf8.patch
- Do not search for translations - broken automake from upstream
  * Not worth fixing only bit italian and mostly hungarian translations
    for cli anyway
* Fri Aug  1 2014 pgajdos@suse.com
- make hunspell work with emacs and utf-8 [bnc#883505]
- added patches:
  * hunspell-emacs-utf8.patch
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 1.3.3:
  - OpenDocument (ODF and Flat ODF) support (ODF needs unzip program)
  - various bug fixes
- removed patches:
  * hashmgr-add-word.patch (upstreamed)
  * hunspell-1.3.2-static-lib.patch (upstreamed)
* Mon May  5 2014 tchvatal@suse.com
- Cleanup with spec-cleaner.
- Do not provide static package. Nothing should staticaly link here
  anyway. With this also remove libtool archive.
- Explicitely disable rpath and name all switches.
- Autoreconf the sources after the patching. Also makes aarch64
  happy this way.
- Paralelize the check phase, no need to run it in just one thread.
- Added patches:
  * hunspell-1.3.2-static-lib.patch
* Fri Feb 21 2014 schwab@linux-m68k.org
- hashmgr-add-word.patch: fix allocation error in HashMgr::add_word (from
  http://sourceforge.net/p/hunspell/patches/49/)
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Sep  3 2012 pgajdos@suse.com
- added /usr/lib64/libhunspell.so on request from egdfree@opensuse.org
* Wed Dec 14 2011 cfarrell@suse.com
- license update: (GPL-2.0+ or LGPL-2.1+ or MPL-1.1+) and LGPL-2.1+
  SPDX syntax describing the COPYING file statesments
* Fri Dec  9 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Mon Sep 26 2011 pgajdos@suse.com
- enhanced description [bnc#718111]
* Mon Mar 28 2011 pgajdos@suse.cz
- update to version 1.3.2:
  * fixes library version inconsistency [bnc#682768]
* Fri Mar 25 2011 idoenmez@novell.com
- Spec cleanup
- Removed hunspell-disable-fortify.patch: we want to build
  with fortify again now that the code is fixed.
* Fri Mar 11 2011 pgajdos@suse.cz
- updated to 1.3.1:
  - new branch
  - bug fixes
* Tue Mar  1 2011 dmueller@suse.de
- update to 1.2.15:
  - bug fixes
  - new options: -r to filter potential mistakes (rare words
    signed by flag WARN in the dictionary)
  - limited and optimized suggestions
* Mon Aug 30 2010 pgajdos@suse.cz
- update to 1.2.12:
  * Maintenance release bug fixes and warnings
- upstreamed fix-format.patch
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Mon Feb 22 2010 meissner@suse.de
- disable FORTIFY_SOURCE, as HashMgr::add_word() and struct hentry
  with "char word;" at the end is not going to work out.
- run "make check" to spot such problems earlier
- added missing format arguments
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Fri Jul 31 2009 mseben@suse.cz
- update to version 1.2.8
  * replist.*, hunspell.cxx, affixmgr.cxx: new input and output
  conversion support
  * tools/wordforms: word generation script for dictionary developers
  * hunspell/hunspell.cxx: extended BREAK feature: ^ and $ mean in break
  patterns the beginning and end of the word.
  * hunspell/hunspell.cxx: set default break at hyphen characters.
  * affixmgr.cxx: SIMPLIFIEDTRIPLE is a new affix file keyword to allow
  simplified forms of the compound words with triple repeating letters.
  * affixmgr.cxx: extend CHECKCOMPOUNDPATTERN to support alternations
  of compound words for example by sandhi feature of Indian and other
  languages.
  * tools/hunspell.cxx: add empty lines as separators to the output of
  the stemming and morphological analysis.
  * affixmgr.cxx: fix condition checking algorithm.
  * affixmgr,cxx: fix COMPOUNDWORDMAX feature.
  * csutil.cxx: fix bad conditional code for Mozilla compilation.
  * hunspell/hunspell.cxx: add missing ngram suggestion for HUHINITCAP
  (capitalized mixed case) words.
  * w_char.hxx: use GCC conditions for GCC related code.
  * affixmgr.cxx: check morphological description in morphgen()
  * tools/affixcompress: extended help for -h (use LC_ALL=C sort
  for input word list)
  * hunspell/hunspell.cxx: remove deprecated word breaking codes.
* Fri Aug 15 2008 lmichnovic@suse.cz
- update to version 1.2.7
  * FULLSTRIP: new option for affix handling. With FULLSTRIP, affix
  rules can strip full words, not only one less characters.
  * COMPOUNDRULE works with all flag types. (COMPOUNDRULE is for
  pattern matching. For example, en_US dictionary of
  OpenOffice.org uses COMPOUNDRULE for ordinal number recognition:
  1st, 2nd, 11th, 12th, 22nd, 112th, 1000122nd etc.).
  * optimized suggestions:
  - modified 1-character distance suggestion algorithms: search
    a TRY character in all position instead of all TRY characters
    in a character position (it can give more readable suggestion
    order, also better suggestions in the first positions, when
    TRY characters are sorted by frequency.)
    For example, suggestions for "moze":
    ooze, doze, Roze, maze, more etc. (Hunspell 1.2.6),
    maze, more, mote, ooze, mole etc. (Hunspell 1.2.7).
  * extended compound word checking for better COMPOUNDRULE related
  suggestions, for example English ordinal numbers: 121323th ->
  121323rd (it needs also a th->rd REP definition).
  * bug fixes (see Changelog)
* Tue Jul 15 2008 lmichnovic@suse.cz
- update to version 1.2.6
  * affentry.cxx: fixes of the affix rule matching algorithm
  (affected only the sk_SK dictionary from all OO.o dictionaries)
  - fix dot pattern + accented letters matching (if not Unicode)
  - word-length conditions work again
  * tests/condition.*: extended test for the fix.
  * hashmgr.cxx: load multiword expressions: spaces may be parts
  of the dictionary words again (but spaces also work as
  morphological field separators: word word2 -> "word word2",
  word po:noun -> "word").
  * man/hunspell.4: updated manual
  * tools/hunspell.cxx: add iconv character conversion support to
  stemming and morphological analysis
* Wed Jul  9 2008 lmichnovic@suse.cz
- update to version 1.2.5
  * fix affix rule condition checking of en_GB dictionary, also
  morphological analysis by dictionaries with two-level suffixes
* Wed Jun 18 2008 lmichnovic@suse.cz
- update to version 1.2.4-2
  with fixed comparison of char* pointer with a string literal
* Tue Jun 17 2008 lmichnovic@suse.cz
- version update Hunspell 1.2.4
  * add free_list() for C, C++ interfaces to deallocate suggestion
  lists
  - Hunspell 1.2.3
  * extended XML interface to use morphological functions by
  standard spell checking interface, spell() and suggest().
  See hunspell.3 manual page.
  * default dash suggestions for compound words: newword-> new word and new-word
  * new manual pages: hunspell.3, hzip.1, hunzip.1.
  * bug fixes
- obsoletes all previous patches
* Fri May  9 2008 aj@suse.de
- Add baselibs.conf.
* Tue May  6 2008 coolo@suse.de
- fix build
* Wed Apr 23 2008 lmichnovic@suse.cz
- fixed libdir and includedir in pkg-config file [bnc#382638]
  (hunspell-pkgconfig_libdir.patch)
* Tue Apr 15 2008 schwab@suse.de
- Avoid libtool namespace clash.
* Sun Apr 13 2008 lmichnovic@suse.cz
- update to 1.2.2 final
  * extended dictionary (dic file) support to use multiple base and
  special dictionaries.
  * new and improved options of command line hunspell:
  - m: morphological analysis or flag debug mode (without affix
  rule data it signs the flag of the affix rules)
  - s: stemming mode
  - D: list available dictionaries and search path
  - d: support extra dictionaries by comma separated list.
  * forbidding in personal dictionary (with asterisk, / signs
  affixation)
  * new affix compression tool "affixcompress": compression tool
  for large (millions of words) dictionaries.
  * improved manual
* Tue Feb 19 2008 lmichnovic@suse.cz
- no need to require %%release
* Thu Feb  7 2008 lmichnovic@suse.cz
- initial version 1.2.2 beta
- fixed uninitilized variable (*uninitialised.patch)
- fixed using function address instead of value
  (*function_address.patch)
